import {BasicColumn, FormSchema} from "@/components/Table";
import {uploadApi} from "@/api/sys/upload";
import {DescItem} from "@/components/Description";

// 搜索栏参数
export const searchFormSchema: FormSchema[] = [
  {
    field: 'keyWord',
    component: 'Input',
    componentProps: {
      placeholder: '搜索资源名称或操作人',
    },
    colProps: {span: 4},
  },
  {
    field: 'ownershipBody',
    label: ' ',
    component: 'Select',
    componentProps: {
      placeholder: '权属机构',
      options: [
        { label: '数据平台治理部', value: '1' },
        { label: '数据资源管理部', value: '2' },
      ],
    },
    colProps: { span: 2 },
  },
  {
    field: 'operationType',
    label: ' ',
    component: 'Select',
    componentProps: {
      placeholder: '操作类型',
      options: [
        { label: '上传', value: '1' },
        { label: '下载', value: '2' },
        { label: '数据集采集', value: '3' },
        { label: '数据集推送', value: '4' },
        { label: 'API调用-拉取数据', value: '5' },
        { label: 'API调用-推送数据', value: '6' },
      ],
    },
    colProps: { span: 2 },
  },
  {
    field: 'affiliatedOrganization',
    label: ' ',
    component: 'Select',
    componentProps: {
      placeholder: '操作人所属机构',
      options: [
        { label: '研发部门', value: '1' },
        { label: '市场部门', value: '2' },
        { label: '测试部门', value: '3' },
        { label: '财务部门', value: '4' },
        { label: '运维部门', value: '5' },
        { label: '数据部门', value: '6' },
        { label: '检查部门', value: '7' },
      ],
    },
    colProps: { span: 3 },
  },
  {
    field: 'pushStatus',
    label: ' ',
    component: 'Select',
    componentProps: {
      placeholder: '状态',
      options: [
        { label: '成功', value: '1' },
        { label: '失败', value: '2' },
      ],
    },
    colProps: { span: 2 },
  },
  {
    field: 'dateRange',
    label: ' ',
    component: 'RangePicker',
    componentProps: {
      format: 'YYYY-MM-DD', // 显示的日期格式
      valueFormat: 'YYYY-MM-DD', // 提交的日期格式
      placeholder: ['开始时间', '结束时间'], // 占位符
      style: { width: '100%' }, // 控制宽度
    },
    colProps: { span: 6 },
  },
];

// 表头列表头
export const columns: BasicColumn[any] = [
  {
    title: '资源名称',
    dataIndex: 'resourceName',
    width: 150,
  },
  {
    title: '权属机构',
    dataIndex: 'ownershipBody',
    width: 150,
  },
  {
    title: '操作人',
    dataIndex: 'updateBy',
    width: 150,
  },
  {
    title: '操作人所属机构',
    dataIndex: 'affiliatedOrganization',
    width: 150,
  },
  {
    title: '操作时间',
    dataIndex: 'updateDate',
    width: 150,
  },
  {
    title: '操作类型',
    dataIndex: 'operationType',
    width: 150,
  },
  {
    title: '推送方式',
    dataIndex: 'pushMode',
    width: 150,
  },
  {
    title: '状态',
    dataIndex: 'pushStatus',
    width: 150,
  },
];
